Crate ginger

Crate ginger 

Ginger-rs

This crate provides implementations of polynomial root finding algorithms.

Modules

  • aberth - Implements the Aberth method for finding the roots of a polynomial.
  • horner - Implements Horner’s method for polynomial evaluation.
  • matrix2 - Implements a simple 2x2 matrix.
  • rootfinding - Implements the Bairstow’s method for finding the roots of a polynomial.
  • leja_order - Implements the Leja ordering.
  • vector2 - Implements a simple 2D vector.
  • vector2_ref - Implements a simple 2D vector reference.

Re-exports

pub use crate::aberth::aberth;
pub use crate::aberth::aberth_autocorr;
pub use crate::aberth::aberth_mt;
pub use crate::aberth::initial_aberth;
pub use crate::aberth::initial_aberth_autocorr;
pub use crate::aberth::poly_from_autocorr_roots;
pub use crate::aberth::poly_from_roots;
pub use crate::horner::horner_eval_c;
pub use crate::horner::horner_eval_f;
pub use crate::matrix2::Matrix2;
pub use crate::rootfinding::extract_autocorr;
pub use crate::rootfinding::initial_autocorr;
pub use crate::rootfinding::initial_guess;
pub use crate::rootfinding::pbairstow_autocorr;
pub use crate::rootfinding::pbairstow_autocorr_mt;
pub use crate::rootfinding::pbairstow_even;
pub use crate::rootfinding::pbairstow_even_mt;
pub use crate::rootfinding::poly_from_autocorr_factors;
pub use crate::rootfinding::poly_from_quadratic_factors;
pub use crate::rootfinding::Options;
pub use crate::vector2::Vector2;

Modules

aberth
This module implements the Aberth method for finding the roots of a polynomial.
horner
This module implements Horner’s method for polynomial evaluation.
leja_order
This module implements the Leja ordering.
matrix2
This module implements a simple 2x2 matrix.
rootfinding
This module implements the Bairstow’s method for finding the roots of a polynomial.
tables
This module provides precomputed low-discrepancy sequence table lookups.
vector2
This module implements a simple 2D vector.
vector2_ref
This module implements a simple 2D vector reference.