Module rootfinding

Module rootfinding 

This module implements the Bairstow’s method for finding the roots of a polynomial.

Structs

Options
The below code defines a struct named Options with three fields: max_iters, tolerance, and tol_ind.

Functions

delta
The delta function calculates the adjustment vector for Bairstow’s method.
delta1
delta 1 for ri - rj
extract_autocorr
The extract_autocorr function extracts quadratic factors from a polynomial with auto-correlation property.
horner
The horner function implements synthetic division by a quadratic factor $$ x^2 - r x - q $$.
initial_autocorr
The initial_autocorr function calculates the initial guesses for Bairstow’s method for finding roots of a polynomial, specifically for the auto-correlation function.
initial_guess
The initial_guess function generates initial quadratic factor estimates for Bairstow’s method.
make_adjoint
The function make_adjoint calculates the adjoint matrix between two vectors.
make_inverse
The function make_inverse calculates the inverse of a 2x2 matrix.
pbairstow_autocorr
The pbairstow_autocorr function implements the simultaneous Bairstow’s method for finding roots of a polynomial, specifically for the auto-correlation function.
pbairstow_autocorr_mt
The pbairstow_autocorr_mt function is a multi-threaded implementation of Bairstow’s method for finding roots of a polynomial, specifically for auto-correlation functions.
pbairstow_even
Parallel Bairstow’s method (even degree only)
pbairstow_even_mt
Multi-threading Bairstow’s method (even degree only)
poly_from_autocorr_factors
Reconstruct a monic polynomial from its autocorrelation quadratic factors
poly_from_quadratic_factors
Reconstruct a monic polynomial from its quadratic factors
suppress
The suppress function in Rust performs zero suppression on a set of vectors.
suppress_old
The suppress_old function performs zero suppression on a set of vectors.