make_adjoint

Function make_adjoint 

pub fn make_adjoint(vr: &Vector2<f64>, vp: &Vector2<f64>) -> Matrix2<f64>
The function make_adjoint calculates the adjoint matrix between two vectors.

$$ \text{adj}!\begin{bmatrix} r & q \ p & s \end{bmatrix} = \begin{bmatrix} s & -p \ -pq & pr+s \end{bmatrix} $$

Arguments:

  • vr: A vector representing the direction of the reference frame’s x-axis.
  • vp: The parameter vp represents a vector vp = (p, s), where p and s are the components of the vector.

Returns:

The function make_adjoint returns a Mat2 object.

  • vp: Another vector representing the row of a 2x2 matrix

Returns:

A 2x2 matrix representing the adjoint